# Husteblume API

import base64
import requests

HEADERS = {
    'user-agent': 'okhttp/4.4.0'
}


def api(method: str, url: str, data: dict = None, user=None) -> requests.Response:
    headers = HEADERS
    if user:
        headers = headers | {
            'authorization': 'Basic ' + (base64.b64encode(f"{user.appId}:{user.password}".encode('ascii'))).decode('ascii')
        }
    m = getattr(requests, method)
    r = m(url, headers=headers, data=data)
    r.raise_for_status()
    return r



import random
import string
from enum import Enum

from husteblume import api


class AgeGroup(Enum):
    UP_TO_TWENTY = 'UP_TO_TWENTY'
    TWENTY_ONE_TO_FORTY = 'TWENTY_ONE_TO_FORTY'
    FORTY_ONE_AND_ABOVE = 'FORTY_ONE_AND_ABOVE'


class Gender(Enum):
    MALE = 'MALE'
    FEMALE = 'FEMALE'
    OTHER = 'OTHER'


class User(object):
    appId: str = ""
    password: str = ""

    @staticmethod
    def register(age_group: AgeGroup, birth_month: int, gender: Gender, password: str = None):
        if password is None:
            password = ''.join(random.choice(string.ascii_letters) for i in range(26))

        r = api('post', 'https://api.husteblume-app.de/users', data=dict(
            age_group=age_group.value, birth_month=birth_month, gender=gender.value, pwd=password
        ))

        u = User(r.json()['appId'], password)
        return u

    def __repr__(self):
        return f"<User: appId={self.appId}>"

    def __init__(self, appId: str, password: str):
        self.appId = appId
        self.password = password



from husteblume import api
from husteblume.user import User


class Stations(object):
    @staticmethod
    def fetch():
        r = api('get', 'https://api.husteblume-app.de/locations?locationType=STATIONS')
        json = r.json()
        result = Stations(json=json)
        return result

    def __init__(self, json: dict):
        self.json = json

    def from_name(self, searchname: str) -> str:
        for station, name in self.json.items():
            if name.lower() == searchname.lower():
                return station

    def from_station(self, searchstation: str) -> str:
        for station, name in self.json.items():
            if station.lower() == searchstation.lower():
                return name


class Regions(object):
    @staticmethod
    def fetch():
        r = api('get', 'https://api.husteblume-app.de/locations?locationType=REGIONS')
        json = r.json()
        result = Regions(json=json)
        return result

    def __init__(self, json: dict):
        self.json = json

    def from_name(self, searchname: str) -> str:
        for station, name in self.json.items():
            if name.lower() == searchname.lower():
                return station

    def from_region(self, searchregion: str) -> str:
        for station, name in self.json.items():
            if station.lower() == searchregion.lower():
                return name


class Forecast(object):
    @staticmethod
    def get(station: str, user: User):
        r = api('get', 'https://api.husteblume-app.de/forecast/' + station, user=user)

        f = Forecast(r.json())
        return f

    def __init__(self, json: dict):
        self.json = json



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="husteblume",
    version="0.0.3",
    author="Sophie Luna Schumann",
    author_email="pypi@sophie.lgbt",
    description="Library to access the TK.de Husteblume API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/SharkyRawr/pyHusteblume",
    project_urls={
        "Bug Tracker": "https://github.com/SharkyRawr/pyHusteblume/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(where="husteblume"),
    python_requires=">=3.6",
    install_requires=[
          'requests',
      ],
)